Module config

Module config 

Configuration loading for GithubClaw.

Loads from two sources:

  • Global: ~/.githubclaw/config.yaml (shared across all repos)
  • Per-repo: .githubclaw/config.yaml (repo-specific overrides)

Structs

E2eConfig
E2E test configuration for Verifier direct-use validation.
GlobalConfig
Global configuration loaded from ~/.githubclaw/config.yaml.
RepoConfig
Per-repo configuration loaded from .githubclaw/config.yaml.

Constants

REPO_CONFIG_DIR_NAME
REPO_CONFIG_FILENAME

Functions

default_event_subscription
find_repo_root
Walk up from start to find a directory containing .git/.
get_log_file
Return the path to the webhook server log file.
get_pid_file
Return the path to the webhook server PID file.
global_config_dir
global_config_path